@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.20>
+<TeXmacs|1.99.11>
 
 <style|<tuple|source|std>>
 
@@ -38,6 +38,8 @@
 
   <assign|screens-bar|<macro|body|<extern|screens-bar|<quote-arg|body>>>>
 
+  <assign|screens-emphasize|<macro|body|<wide*|<arg|body>|\<wide-bar\>>>>
+
   <\active*>
     <\src-comment>
       Global document layout
@@ -50,6 +52,18 @@
 
   <assign|page-orientation|landscape>
 
+  <assign|page-odd|5mm>
+
+  <assign|page-even|5mm>
+
+  <assign|page-right|5mm>
+
+  <assign|page-top|5mm>
+
+  <assign|page-bot|5mm>
+
+  <assign|page-screen-margin|false>
+
   <assign|page-screen-left|5mm>
 
   <assign|page-screen-right|5mm>
@@ -66,6 +80,10 @@
 
   <assign|item-vsep|<macro|0fn>>
 
+  <assign|page-odd-footer|>
+
+  <assign|page-even-footer|>
+
   <\active*>
     <\src-comment>
       Titles
@@ -74,10 +92,22 @@
 
   <assign|title-theme|title-bar>
 
+  <assign|title-vpadding|1spc>
+
+  <assign|title-font-size|1.414>
+
+  <assign|title-old-style|false>
+
   <assign|title-bar-color|<macro|dark blue>>
 
   <assign|title-color|<macro|white>>
 
+  <assign|title-border|0ln>
+
+  <assign|title-sunny-color|#f4f4ff>
+
+  <assign|title-shadow-color|#d8d8ff>
+
   <assign|title-left|<macro|body|>>
 
   <assign|title-right|<macro|body|>>
@@ -86,20 +116,46 @@
 
   <assign|title-right|<macro|body|<screens-summary|<quote-arg|body>>>>
 
+  <assign|title-|>
+
+  <drd-props|title-vpadding|macro-parameter|length>
+
+  <drd-props|title-font-size|macro-parameter|font-size>
+
+  <drd-props|title-old-style|macro-parameter|boolean>
+
   <drd-props|title-bar-color|macro-parameter|color>
 
   <drd-props|title-color|macro-parameter|color>
 
-  <assign|tit|<macro|body|<with|color|<title-color>|math-color|<title-color>|ornament-color|<title-bar-color>|<ornament|<title-left|<arg|body>><htab|5mm><with|font-series|bold|math-font-series|bold|<large|<space|0em|-0.6ex|1.6ex><arg|body>>><htab|5mm><title-right|<arg|body>>>>>>
+  <assign|with-tit-color|<macro|body|<\with|color|<title-color>|math-color|<title-color>|strong-color|<title-color>>
+    <arg|body>
+  </with>>>
+
+  <assign|tit|<macro|body|<with-tit-color|<with|ornament-color|<title-bar-color>|<ornament|<title-left|<arg|body>><htab|5mm><with|font-series|bold|math-font-series|bold|<large|<space|0em|-0.6ex|1.6ex><arg|body>>><htab|5mm><title-right|<arg|body>>>>>>>
 
   <assign|tit|<\macro|body>
-    <\with|par-left|<minus|<value|page-screen-left>>|par-right|<minus|<value|page-screen-right>>>
-      <shift|<with|color|<title-color>|math-color|<title-color>|<resize|<tabular*|<tformat|<twith|table-width|1par>|<twith|table-hmode|exact>|<cwith|1|1|1|-1|cell-background|<title-bar-color>>|<cwith|1|1|1|1|cell-halign|c>|<cwith|1|1|1|1|cell-hyphen|t>|<twith|table-valign|T>|<table|<row|<\cell>
-        <title-left|<arg|body>><htab|5mm><arg|body><htab|5mm><title-right|<arg|body>>
-      </cell>>>>>||0em||>>|0mm|<value|page-screen-top>>
-    </with>
+    <\surround|<assign|page-this-top|0mm>|<assign|gpag-length|<macro|<minus|1pag|2.25fn>>><vspace|5mm>>
+      <\with|par-left|<minus|<value|page-odd>>|par-right|<minus|<value|page-right>>|color|<value|title-shadow-color>>
+        <with|<resize|<tabular*|<tformat|<twith|table-width|1par>|<twith|table-hmode|exact>|<cwith|1|1|1|-1|cell-background|<title-bar-color>>|<cwith|1|1|1|1|cell-halign|c>|<cwith|1|1|1|1|cell-hyphen|t>|<twith|table-valign|T>|<cwith|1|1|1|1|cell-tborder|<value|title-border>>|<cwith|1|1|1|1|cell-bborder|<value|title-border>>|<cwith|1|1|1|1|cell-lborder|<value|title-border>>|<cwith|1|1|1|1|cell-rborder|<value|title-border>>|<table|<row|<\cell>
+          <with-tit-color|<title-left|<arg|body>><htab|5mm><arg|body><htab|5mm><title-right|<arg|body>>>
+        </cell>>>>>||0em||>>
+      </with>
+    </surround>
   </macro>>
 
+  <\active*>
+    <\src-comment>
+      Customized screens
+    </src-comment>
+  </active*>
+
+  <assign|with-screen-color|<\macro|col|body>
+    <surround|<assign|page-this-bg-color|<arg|col>>||<arg|body>>
+  </macro>>
+
+  <drd-props|with-screen-color|arity|2|hidden|0|accessible|1|border|no>
+
   <\active*>
     <\src-comment>
       Customized session elements
